from orionis.luminate.services.workers.maximum_workers import MaximumWorkers

__all__ = [
    "MaximumWorkers",
]
__author__ = "Raúl Mauricio Uñate Castro"
__description__ = (
    "This module provides a class to calculate the maximum number of workers "
    "that can be run on a machine based on its CPU and memory resources. "
)