from orionis.luminate.services.paths.resolver import Resolver

__all__ = [
    "Resolver",
]
__author__ = "Raúl Mauricio Uñate Castro"
__description__ = (
    "This module provides a Resolver class that is used to resolve paths in the Orionis Framework application. "
)