from orionis.luminate.config.cache.entities.cache import Cache

__all__ = [
    "Cache",
]
__author__ = "Raúl Mauricio Uñate Castro"
__description__ = (
    "This dataclass defines the structure of the cache configuration. "
)