from orionis.luminate.services.environment.env import Env

__all__ = [
    "Env",
]
__author__ = "Raúl Mauricio Uñate Castro"
__description__ = (
    "This module provides a singleton class to manage environment variables. "
    "It allows setting, getting, and deleting environment variables."
)