import unittest
from orionis.luminate.test.output.test_std_out import TestStdOut

class SyncTestCase(unittest.TestCase, TestStdOut):
    """
    SyncTestCase is a test case class designed for synchronous unit testing.
    It inherits from `unittest.TestCase` to provide support for standard test methods
    and `TestStdOut` for additional functionality.
    """

    pass