from orionis.luminate.config.app.entities.app import App

__all__ = [
    "app"
]
__author__ = "Raúl Mauricio Uñate Castro"
__description__ = (
    "This dataclass defines the main configuration of the Orionis Framework application. "
    "Its design aims to provide a flexible and adaptable structure for Python projects."
)