from orionis.luminate.config.auth.entities.auth import Auth

__all__ = [
    "Auth",
]
__author__ = "Raul Mauricio Uñate Castro"
__description__ = "This module exports a dataclass that contains the required properties to configure an Orionis application"